[![Build Status](https://travis-ci.com/Haytek/swy.svg?branch=master)](https://travis-ci.com/Haytek/swy)
[![Coverage Status](https://coveralls.io/repos/github/Haytek/swy/badge.svg?branch=master)](https://coveralls.io/github/Haytek/swy?branch=master)
![PyPI](https://img.shields.io/pypi/v/swy)

# swy

yop
